/*
 * ULS_Support.c
 *
 *  Created on: Mar 21, 2015
 *      Author: Jim Lacenski, jlacenski@centurylink.net
 *      Not for commercial use
 */
#include <msp430.h>
extern unsigned int DutyCycle;
extern unsigned char UpDown, DCONOFF, DarkLight;

void InitPorts()
{
    // set up ports
    // port 1            7     6      5     4     3      2      1      0
    //                  in    out    in    out   in                   out
    //                 DCON   PWM   photo  load  PB     n/c    n/c    LED
    P1OUT &= 0x00;
    P1DIR &= 0x00;
    P1DIR |= BIT6 + BIT4 + BIT0;	// output on 1.6, 1.4 and 1.0
    // Bits 2 and 1    			    // reserved for UART
    P1SEL |= BIT6;  				// select PWM to pin 6
    P1REN |= BIT5;					// resistor enable
    P1OUT |= BIT5;					// turn on pull up (photocell)
    P1REN |= BIT3;					// resistor enable
    P1OUT |= BIT3;					// turn on pull up (pushbutton)
    P1DIR |= BIT2 + BIT1;			// set 1.2 and 1.1 for output


    P1IE  |= BIT3;					// interrupt enable on pushbutton
    P1IES |= BIT3;					// hi to low edge
    P1IFG &= ~BIT3; 				// clear flag
    P1OUT &= ~BIT0;					// initialize debug out (LED) to low

    P1OUT |= BIT4;					// Load control on/off output ON
    __delay_cycles(40000);
    P1OUT &= ~BIT4;					// turn load off

    P2OUT &= 0x00;					// initialize unused port
    P2DIR &= 0xFF;

}

void InitTimers()
{
    // set up timers
    // PWM timer
    CCR0 = 50-1;
    CCTL1 = OUTMOD_7;
    CCR1 = DutyCycle;
    TACTL = TASSEL_2 + MC_0;  // leave timer off initially

    // ~.25 sec polling timer
    TA1CCTL0 = CCIE;		// interrupt enable
    TA1CCR0 = 32000;
    TA1CTL = TASSEL_2 + MC_1 + ID_3;  // SMCLK + up to CCR0 + divide by 8
}

void PWMControl(unsigned char OnOff)
{
  volatile unsigned char PWMIsOn = 0;

  if ((OnOff == 1) && (PWMIsOn == 0))
  {   P1SEL |= BIT6;  				// select timer (PWM) to pin 6
	  TACTL = TASSEL_2 + MC_1;      // load control register to start PWM
	  PWMIsOn = 1;
	  P1OUT |= BIT0;  }       		// turn on (debugging use) indicator

  if (OnOff == 0)			        // turn off PWM with this code
  	  	  	  { P1SEL &= ~BIT6;  				// force back to non-PWM port mode
  	  	        P1DIR |= BIT6;					// set to output
  	  	        P1OUT &= ~BIT6;					// set low
	  	  	  	TACTL = TASSEL_2 + OUTMOD_1 + MC_0;
  	  	        TACTL = TASSEL_2 + OUTMOD_1;
  	  	        PWMIsOn = 0;
  	  	        P1OUT &= ~BIT0; }   // indicator off
}

