#include <msp430.h>

/* full logic, 1 hour 30 to shutdown
 * main.c  Jim Lacenski    not for commercial use
 * see http://www.msp430launchpad.com/2010/07/timers-and-clocks-and-pwm-oh-my.html
 * and http://www.embeddedrelated.com/showarticle/182.php
 * 9 April 2015
 */

#include "ULS_Support.h"


int main(void) {
    WDTCTL = WDTPW | WDTHOLD;		// Stop watchdog timer
    DutyCycle = (DCHIGH / 2) + 5;	// initialize to near standard brightness
    UpDown = 1; DarkLight = 0; DurationCount = 0;

    InitPorts();
    InitTimers();

	while (1)
	{

    _BIS_SR(LPM0_bits | GIE);        // Enter LPM0 (sleep) until interrupt
    // woke up, state handling. see truth table in include file

	 // power on, light, toggle of zero: 	turn PWM off, load off and reset timeout
	 if ((DCONOFF == 1) && (DarkLight == 0) && (Toggle == 0))
	 	 	  	  		 	 {PWMControl(0);
	 	 	  	  		      P1OUT &= ~BIT4;		// load off
	 	 	  	  		      DurationCount = 0;}   // reset count

	 // power on, dark, toggle don't care: 	turn PWM off, load on, and reset timeout
	 if ((DCONOFF == 1) && (DarkLight == 1))
	 	 	  	  		 	 {PWMControl(0);
	 	 	  	  		      P1OUT |= BIT4;		// load on
	 	 	  	  		      DurationCount = 0;}   // reset count

	 // power on, light, toggle 1: 			turn PWM off, load on, and reset timeout
	 if ((DCONOFF == 1) && (DarkLight == 0) && (Toggle == 1))
	 	 	  	  		 	 {PWMControl(0);
	 	 	  	  		      P1OUT |= BIT4;		// load on
	 	 	  	  		      DurationCount = 0;}   // reset count


    // power off and dark, duration under max: 		turn PWM on, load on
	 if ((DCONOFF == 0) && (DarkLight == 1) && (DurationCount < MaxDuration ))
	 	 	 	 	 	 	 {PWMControl(1);
	 	 	  	  		      P1OUT |= BIT4;		// load on
	 	 	  	  		      DurationCount++;}

	 // power off but timeout condition: turn off PWM and load
	 if ((DCONOFF == 0) && (DurationCount >= MaxDuration))
	 	 	 	 	 	 {PWMControl(0);
	 	 	 	 	 	 P1OUT &= ~BIT4;	 }

	 // power off but light detected: turn PWM off, load off
	 if ((DCONOFF == 0) && (DarkLight == 0) )
	 	 	 	 	 	 	 {  PWMControl(0);
	 	 	  	  	            P1OUT &= ~BIT4;		// load off
	 	 	  	  	            DurationCount=0;}

	}
	return 0;
}

#pragma vector=PORT1_VECTOR			// handles pushbutton for duty cycle and toggle
__interrupt void PORT1_ISR(void)
{
   // handle brightness control during battery power
   if ((DutyCycle < DCHIGH) && (UpDown == 1) && (DCONOFF == 0))
   {
   DutyCycle = DutyCycle + 5;
   CCR1 = DutyCycle;
   }

   if ((DutyCycle > DCLOW) && (UpDown == 0) && (DCONOFF == 0))
   {
   DutyCycle = DutyCycle - 5;
   CCR1 = DutyCycle;
   }

   if (DutyCycle >= DCHIGH)
   	   	   { UpDown = 0; CCR1 = DutyCycle = DCHIGH;  }

   if (DutyCycle <= DCLOW)
   	   { UpDown = 1; CCR1 = DutyCycle = DCLOW;  }


   // handle toggle when source power on
   if (DCONOFF==1)
   { if (Toggle == 0)
   	   { Toggle = 1;} else {Toggle = 0; }
   }


   P1IFG &=~BIT3;                        // P1.3 IFG cleared
}

#pragma vector=TIMER1_A0_VECTOR
__interrupt void TIMER1_ISR(void)		// polling timer
{
	DarkLight = (P1IN & BIT5) >> 5;
	DCONOFF = (P1IN & BIT7) >> 7;
	__bic_SR_register_on_exit(LPM3_bits);		// wakeup main loop
}


